package ecp.vcs.com.ecpsyncplugin.re_sync.storage;

import android.content.Context;
import android.os.Build;
import android.os.Environment;

import java.io.File;

import ecp.vcs.com.ecpsyncplugin.re_sync.logging.LogHelper;
import ecp.vcs.com.ecpsyncplugin.re_sync.networking.AppUtil;


public class ScopedStorage {

    private static ScopedStorage sInstance;
    private final Context context;

    public static final String EXTERNAL_STORAGE_CPM_MANUAL = "CPM_Manual";
    public static final String EXTERNAL_STORAGE_UPLOAD_TXT = "RE_CPM_UPLOAD_TXT_FILE";
    public static final String EXTERNAL_STORAGE_SYNC_LOG = ".re_cpm_sync_log";
    public static final String SEND_JSON = "sendJson";
    public static final String ACCOUNT_TEMP = "ACCOUNT_TMP";
    //For Bulk Reading
    public static final String BULK_TXT_READING = "RE_CPM_UPLOAD_TXT_FILE";
    //For Sync
    public static final String EXTERNAL_STORAGE_RECPM_SYNC_REQUEST= "RECPM_SYNC_REQUEST";
    public static final String EXTERNAL_STORAGE_SYNC_RESPONSE_DEV= "RE_CPM_SYNC_RESPONSE_DEV";
    //For Yellow Label
    public static final String REQUEST_YELLOW_LABEL = "RECPM_YELLOW_LABEL";
    public static final String REQUEST_YELLOW_LABEL_DOWNLOAD = "RECPM_YELLOW_LABEL_DOWNLOAD";
    //For Retailer Return
    public static final String REQUEST_RETAILER_RETURN = "RECPM/RETAILER_RETURN";
    public static final String REQUEST_RETAILER_RETURN_DOWNLOAD = "RECPM/RETAILER_RETURN_RESPONSE";
    //For WH Dist Return CheckOnline
    public static final String REQUEST_WH_DIST = "RECPM/WH_DIST_RETURN";
    public static final String REQUEST_WH_DIST_DOWNLOAD = "RECPM/WH_DIST_RETURN_RESPONSE";
    //For Check Online
    public static final String REQUEST_CHECK_ONLINE = "RECPM_SYNC_CHECK_ONLINE";
    //Label Support
    public static final String REQUEST_LABEL_SUPPORT = "RECPM/LABELSUPPORT";
    //Video Manual
    public static final String downloadDirectory = "RE_CPM_VIDEO_MANUAL";
    //CPM Database Export Location
    public static final String RECPM_DB = "RE_CPM_DB";
    //Hidden apk
    public static final String HIDDEN_APK = ".R_APK";
    //PROFILE Image selection in MYAccount
    public static final String PROFILE = "PROFILE";

    public static final String ECTERNAL_STORAGE_APP_LOG_FILE = "/LOG";

    public ScopedStorage(Context context) {
        this.context=context;
    }

    public static synchronized ScopedStorage getInstance(Context context) {
        if (sInstance == null) {
            sInstance = new ScopedStorage(context);
        }
        return sInstance;
    }

    //Create Folder
    public void createFolders(String fileName) {
        try {
            File root;
            // Check if we're running on Android P(Pie) or higher
            if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.P) {
                root = new File(Environment.getExternalStorageDirectory(), fileName);
            } else {
                root = new File(context.getFilesDir(), fileName);
            }
            if (!root.exists()) {
                root.mkdirs();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    //Create Folder
    public File createDelete(String fileName) {
        File root = null;
        try {
            if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.P) {
                root = new File(Environment.getExternalStorageDirectory(), fileName);
            }else {
                root = new File(context.getFilesDir(), fileName);
            }

            if (!root.exists()) {
                root.mkdirs();
            }else {
                AppUtil.deleteAllFiles(root);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

        return root;
    }


    /**
     * Get Full Path
     * @param fileName
     * Note: Path will return path without / at the end
     * @return
     */
    public String getPath(String fileName){
        String path="";
        try {
            File root;
            if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.P) {
                root = new File(Environment.getExternalStorageDirectory(), fileName);
                if (!root.exists()) {
                    path=root.getAbsolutePath();
                }else {
                    path=Environment.getExternalStorageDirectory().toString()+"/"+fileName;
                }
            }else {
                root = new File(context.getFilesDir(), fileName);
                if (!root.exists()) {
                    path=root.getAbsolutePath();
                }else {
                    path=context.getFilesDir().toString()+"/"+fileName;
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
//        if (path.isEmpty()){
//            path=context.getFilesDir().toString()+"/"+fileName;
//        }
        LogHelper.printLog("TAG_GETPATH",path);
        return path;
    }

    public String getDirPath() {
        String path="";
        if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.P) {
            path = Environment.getExternalStorageDirectory().getPath();
        }else {
            path=context.getFilesDir().getPath();
        }
        return path;
    }

    /**
     * Get Full Path
     * @param fileName
     * Note: Path will return path without / at the end
     * @return
     */
    public String getPathBulk(String fileName){
        String path="";
        try {
            File root;
            if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.Q) {
                root = new File(Environment.getExternalStorageDirectory(), fileName);
                if (!root.exists()) {
                    path=root.getAbsolutePath();
                }else {
                    path=Environment.getExternalStorageDirectory().toString()+"/"+fileName;
                }
            }else {
                root = new File(context.getFilesDir(), fileName);
                if (!root.exists()) {
                    path=root.getAbsolutePath();
                }else {
                    path=context.getFilesDir().toString()+"/"+fileName;
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
//        if (path.isEmpty()){
//            path=context.getFilesDir().toString()+"/"+fileName;
//        }
        LogHelper.printLog("TAG_GETPATH",path);
        return path;
    }
}
