//
//  FileUploader.swift
//  ecp_sync_plugin
//
//  Created by Jalpa Dhaval Sodha Parmar on 08/01/24.
//

import Foundation

func uploadImage(fileName: String, image: UIImage, token:String, user_id:String, upload_type:String, first_sync:String) {
    let url = URL(string: "http://api-host-name/v1/api/uploadfile/single")

    // generate boundary string using a unique per-app string
    let boundary = UUID().uuidString

    let session = URLSession.shared

    // Set the URLRequest to POST and to the specified URL
    var urlRequest = URLRequest(url: url!)
    urlRequest.httpMethod = "POST"

    // Set Content-Type Header to multipart/form-data, this is equivalent to submitting form data with file upload in a web browser
    // And the boundary is also set here
    urlRequest.setValue("multipart/form-data; boundary=\(boundary)", forHTTPHeaderField: "Content-Type")
    urlRequest.setValue("Keep-Alive", forHTTPHeaderField: "Connection")

    var data = Data()

    // Add the image data to the raw http request data
    data.append("\r\n--\(boundary)\r\n".data(using: .utf8)!)
    data.append("Content-Disposition: form-data; filename=\"\(fileName)\"; token=\"\(token)\"; user_id=\"\(user_id)\"; upload_type=\"\(upload_type)\"; first_sync=\"\(first_sync)\"; \r\n".data(using: .utf8)!)
    data.append("Content-Type: image/png\r\n\r\n".data(using: .utf8)!)
    data.append(image.pngData()!)

    data.append("\r\n--\(boundary)--\r\n".data(using: .utf8)!)

    // Send a POST request to the URL, with the data we created earlier
    session.uploadTask(with: urlRequest, from: data, completionHandler: { responseData, response, error in
        if error == nil {
            let jsonData = try? JSONSerialization.jsonObject(with: responseData!, options: .allowFragments)
            if let json = jsonData as? [String: Any] {
                print(json)
            }
        }
    }).resume()
}


func uploadFileWithType(filePath: String, uploadUrl: String, uploadType: String, startProgress: Int, endProgress: Int, syncType: String, token: String, imeiNumber: String, userID: String) {
    var exceptionDetails = ""
    var FUpload_Start = Date().timeIntervalSince1970 * 1000
    var callbackProgress = startProgress
    
    guard let sourceFile = URL(string: filePath) else {
        // Handle invalid file path
        return
    }
    
    do {
        let fileData = try Data(contentsOf: sourceFile)
        let boundary = "------fileUpload"
        
        var urlRequest = URLRequest(url: URL(string: uploadUrl)!)
        urlRequest.httpMethod = "POST"
        urlRequest.setValue("Keep-Alive", forHTTPHeaderField: "Connection")
        urlRequest.setValue("multipart/form-data; boundary=\(boundary)", forHTTPHeaderField: "Content-Type")
        urlRequest.setValue("filename", forHTTPHeaderField: "filename")
        urlRequest.setValue(filePath, forHTTPHeaderField: "filePath")
        urlRequest.setValue(token, forHTTPHeaderField: "token")
        urlRequest.setValue(userID, forHTTPHeaderField: "user_id")
        urlRequest.setValue(uploadType, forHTTPHeaderField: "upload_type")
        urlRequest.setValue(syncType != nil && syncType.lowercased() != "f" ? "" : filePath, forHTTPHeaderField: "filename")
        urlRequest.setValue(imeiNumber, forHTTPHeaderField: "imei_no")
        
        let body = NSMutableData()
        body.appendString("\r\n--\(boundary)\r\n")
        body.appendString("Content-Disposition: form-data; name=\"file\"; filename=\"\(filePath)\"\r\n")
        body.appendString("Content-Type: application/octet-stream\r\n\r\n")
        body.append(fileData)
        body.appendString("\r\n--\(boundary)--\r\n")
        
        urlRequest.httpBody = body as Data
        
        let task = URLSession.shared.dataTask(with: urlRequest) { data, response, error in
            guard let data = data, let response = response as? HTTPURLResponse, error == nil else {
                // Handle error
                return
            }
            
            // Handle the server response
            // ...
        }
        
        task.resume()
    } catch {
        exceptionDetails = error.localizedDescription
        // Handle file data reading error
    }
}

extension NSMutableData {
    func appendString(_ string: String) {
        if let data = string.data(using: .utf8) {
            append(data)
        }
    }
}


